@@ -1,16 +1,18 @@
 package Stuff::Exception;
 
-use Stuff qw/ Exporter /;
+use Stuff 'Exporter';
 use Scalar::Util qw/ blessed /;
 use Stuff::Base::Exception;
 use Stuff::Base::Error;
 
+our %expected;
 our @EXPORT_OK = qw/ error rethrow try catch /;
 
+# 
 my $exception_class = 'Stuff::Base::Exception';
-my $error_class = 'Stuff::Base::Error';
+my $error_class     = 'Stuff::Base::Error';
 
-sub error {
+sub error($@) {
   $error_class->throw( @_ );
 }
 
@@ -23,8 +25,6 @@ sub rethrow(;$) {
   $error_class->throw( $e );
 }
 
-our %expected;
-
 sub try(&) {
   my $code = shift;
   
@@ -51,13 +51,20 @@ sub catch(&$) {
   return;
 }
 
-sub croak {
-  for( $_[0] ) {
-    die $_ if $_ =~ /\n/;
-    
-    my( $file, $line ) = ( caller( 1 + $_[1] ) )[1,2];
-    die "$_ at $file line $line.\n";
-  }
-}
-
 1;
+
+=head1 NAME
+
+Stuff::Exception - Exception handling stuff
+
+=head1 LICENSE
+
+This program is free software, you can redistribute it and/or modify it under
+the terms of the Artistic License 2.0.
+
+=head1 AUTHOR
+
+Nikita Zubkov E<lt>nikzubkov@gmail.comE<gt>.
+
+=cut
+
